@@ -14,8 +14,7 @@ from saveddit.subreddit_downloader import SubredditDownloader
 import sys
 from tqdm import tqdm
 
-
-class UserDownloader():
+class UserDownloader:
     config = SubredditDownloader.config
 
     REDDIT_CLIENT_ID = config['reddit_client_id']
@@ -37,11 +36,6 @@ class UserDownloader():
             REDDIT_PASSWORD = sys.stdin.readline().rstrip()
 
     IMGUR_CLIENT_ID = config['imgur_client_id']
-    DEFAULT_CATEGORIES = ["comments", "submitted", "saved"]
-    DEFAULT_SORT = "hot"
-    DEFAULT_SORT_OPTIONS = ["hot", "new", "top", "controversial"]
-    DEFAULT_POST_LIMIT = None
-    DEFAULT_COMMENT_LIMIT = None
 
     def __init__(self):
         self.logger = verboselogs.VerboseLogger(__name__)
@@ -82,6 +76,38 @@ class UserDownloader():
             password=UserDownloader.REDDIT_PASSWORD
         )
 
+    def download_user_meta(self, args):
+        output_path = args.o
+
+        for username in args.users:
+            user = self.reddit.redditor(name=username)
+
+            root_dir = os.path.join(os.path.join(os.path.join(
+                output_path, "www.reddit.com"), "u"), username)
+
+            if not os.path.exists(root_dir):
+                os.makedirs(root_dir)
+
+            with open(os.path.join(root_dir, 'user.json'), 'w') as file:
+                user_dict = {}
+                user_dict["comment_karma"] = user.comment_karma
+                user_dict["created_utc"] = int(user.created_utc)
+                user_dict["has_verified_email"] = user.has_verified_email
+                user_dict["icon_img"] = user.icon_img
+                user_dict["id"] = user.id
+                user_dict["is_employee"] = user.is_employee
+                user_dict["is_friend"] = user.is_friend
+                user_dict["is_mod"] = user.is_mod
+                user_dict["is_gold"] = user.is_gold
+                try:
+                    user_dict["is_suspended"] = user.is_suspended
+                except Exception as e:
+                    user_dict["is_suspended"] = None
+                user_dict["link_karma"] = user.link_karma
+                user_dict["name"] = user.name
+
+                file.write(json.dumps(user_dict, indent=2))
+
     def download_comments(self, args):
         output_path = args.o
 
